# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import ponsim_pb2 as voltha__protos_dot_ponsim__pb2


class PonSimStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.SendFrame = channel.unary_unary(
        '/voltha.PonSim/SendFrame',
        request_serializer=voltha__protos_dot_ponsim__pb2.PonSimFrame.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.ReceiveFrames = channel.unary_stream(
        '/voltha.PonSim/ReceiveFrames',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=voltha__protos_dot_ponsim__pb2.PonSimFrame.FromString,
        )
    self.GetDeviceInfo = channel.unary_unary(
        '/voltha.PonSim/GetDeviceInfo',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=voltha__protos_dot_ponsim__pb2.PonSimDeviceInfo.FromString,
        )
    self.UpdateFlowTable = channel.unary_unary(
        '/voltha.PonSim/UpdateFlowTable',
        request_serializer=voltha__protos_dot_ponsim__pb2.FlowTable.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.GetStats = channel.unary_unary(
        '/voltha.PonSim/GetStats',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=voltha__protos_dot_ponsim__pb2.PonSimMetrics.FromString,
        )


class PonSimServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def SendFrame(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ReceiveFrames(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetDeviceInfo(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateFlowTable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetStats(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_PonSimServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'SendFrame': grpc.unary_unary_rpc_method_handler(
          servicer.SendFrame,
          request_deserializer=voltha__protos_dot_ponsim__pb2.PonSimFrame.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'ReceiveFrames': grpc.unary_stream_rpc_method_handler(
          servicer.ReceiveFrames,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=voltha__protos_dot_ponsim__pb2.PonSimFrame.SerializeToString,
      ),
      'GetDeviceInfo': grpc.unary_unary_rpc_method_handler(
          servicer.GetDeviceInfo,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=voltha__protos_dot_ponsim__pb2.PonSimDeviceInfo.SerializeToString,
      ),
      'UpdateFlowTable': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateFlowTable,
          request_deserializer=voltha__protos_dot_ponsim__pb2.FlowTable.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'GetStats': grpc.unary_unary_rpc_method_handler(
          servicer.GetStats,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=voltha__protos_dot_ponsim__pb2.PonSimMetrics.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'voltha.PonSim', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/yang_options.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/yang_options.proto',
  package='common',
  syntax='proto3',
  serialized_options=_b('Z.github.com/opencord/voltha-protos/v2/go/common'),
  serialized_pb=_b('\n voltha_protos/yang_options.proto\x12\x06\x63ommon\x1a google/protobuf/descriptor.proto\"&\n\nInlineNode\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"8\n\x0cRpcReturnDef\x12\x0f\n\x07xml_tag\x18\x01 \x01(\t\x12\x17\n\x0flist_items_name\x18\x02 \x01(\t*W\n\x13MessageParserOption\x12\x18\n\x14MOVE_TO_PARENT_LEVEL\x10\x00\x12&\n\"CREATE_BOTH_GROUPING_AND_CONTAINER\x10\x01:X\n\x0fyang_child_rule\x12\x1f.google.protobuf.MessageOptions\x18\xee\xde\xd9\x03 \x01(\x0e\x32\x1b.common.MessageParserOption:Z\n\x11yang_message_rule\x12\x1f.google.protobuf.MessageOptions\x18\xef\xde\xd9\x03 \x01(\x0e\x32\x1b.common.MessageParserOption:N\n\x10yang_inline_node\x12\x1d.google.protobuf.FieldOptions\x18\xf0\xde\xd9\x03 \x01(\x0b\x32\x12.common.InlineNode:M\n\x0cyang_xml_tag\x12\x1e.google.protobuf.MethodOptions\x18\xf1\xde\xd9\x03 \x01(\x0b\x32\x14.common.RpcReturnDefB0Z.github.com/opencord/voltha-protos/v2/go/commonb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])

_MESSAGEPARSEROPTION = _descriptor.EnumDescriptor(
  name='MessageParserOption',
  full_name='common.MessageParserOption',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MOVE_TO_PARENT_LEVEL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CREATE_BOTH_GROUPING_AND_CONTAINER', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=176,
  serialized_end=263,
)
_sym_db.RegisterEnumDescriptor(_MESSAGEPARSEROPTION)

MessageParserOption = enum_type_wrapper.EnumTypeWrapper(_MESSAGEPARSEROPTION)
MOVE_TO_PARENT_LEVEL = 0
CREATE_BOTH_GROUPING_AND_CONTAINER = 1

YANG_CHILD_RULE_FIELD_NUMBER = 7761774
yang_child_rule = _descriptor.FieldDescriptor(
  name='yang_child_rule', full_name='common.yang_child_rule', index=0,
  number=7761774, type=14, cpp_type=8, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
YANG_MESSAGE_RULE_FIELD_NUMBER = 7761775
yang_message_rule = _descriptor.FieldDescriptor(
  name='yang_message_rule', full_name='common.yang_message_rule', index=1,
  number=7761775, type=14, cpp_type=8, label=1,
  has_default_value=False, default_value=0,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
YANG_INLINE_NODE_FIELD_NUMBER = 7761776
yang_inline_node = _descriptor.FieldDescriptor(
  name='yang_inline_node', full_name='common.yang_inline_node', index=2,
  number=7761776, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)
YANG_XML_TAG_FIELD_NUMBER = 7761777
yang_xml_tag = _descriptor.FieldDescriptor(
  name='yang_xml_tag', full_name='common.yang_xml_tag', index=3,
  number=7761777, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR)


_INLINENODE = _descriptor.Descriptor(
  name='InlineNode',
  full_name='common.InlineNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='common.InlineNode.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='common.InlineNode.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=116,
)


_RPCRETURNDEF = _descriptor.Descriptor(
  name='RpcReturnDef',
  full_name='common.RpcReturnDef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='xml_tag', full_name='common.RpcReturnDef.xml_tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_items_name', full_name='common.RpcReturnDef.list_items_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=174,
)

DESCRIPTOR.message_types_by_name['InlineNode'] = _INLINENODE
DESCRIPTOR.message_types_by_name['RpcReturnDef'] = _RPCRETURNDEF
DESCRIPTOR.enum_types_by_name['MessageParserOption'] = _MESSAGEPARSEROPTION
DESCRIPTOR.extensions_by_name['yang_child_rule'] = yang_child_rule
DESCRIPTOR.extensions_by_name['yang_message_rule'] = yang_message_rule
DESCRIPTOR.extensions_by_name['yang_inline_node'] = yang_inline_node
DESCRIPTOR.extensions_by_name['yang_xml_tag'] = yang_xml_tag
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InlineNode = _reflection.GeneratedProtocolMessageType('InlineNode', (_message.Message,), {
  'DESCRIPTOR' : _INLINENODE,
  '__module__' : 'voltha_protos.yang_options_pb2'
  # @@protoc_insertion_point(class_scope:common.InlineNode)
  })
_sym_db.RegisterMessage(InlineNode)

RpcReturnDef = _reflection.GeneratedProtocolMessageType('RpcReturnDef', (_message.Message,), {
  'DESCRIPTOR' : _RPCRETURNDEF,
  '__module__' : 'voltha_protos.yang_options_pb2'
  # @@protoc_insertion_point(class_scope:common.RpcReturnDef)
  })
_sym_db.RegisterMessage(RpcReturnDef)

yang_child_rule.enum_type = _MESSAGEPARSEROPTION
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(yang_child_rule)
yang_message_rule.enum_type = _MESSAGEPARSEROPTION
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(yang_message_rule)
yang_inline_node.message_type = _INLINENODE
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(yang_inline_node)
yang_xml_tag.message_type = _RPCRETURNDEF
google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(yang_xml_tag)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2


class HealthServiceStub(object):
  """Health related services
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetHealthStatus = channel.unary_unary(
        '/voltha.HealthService/GetHealthStatus',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=voltha__protos_dot_health__pb2.HealthStatus.FromString,
        )


class HealthServiceServicer(object):
  """Health related services
  """

  def GetHealthStatus(self, request, context):
    """Return current health status of a Voltha instance
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_HealthServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetHealthStatus': grpc.unary_unary_rpc_method_handler(
          servicer.GetHealthStatus,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=voltha__protos_dot_health__pb2.HealthStatus.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'voltha.HealthService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
